@@ -89,6 +89,10 @@ if (EXTERNAL_UNMANAGED_SSL := data.get("PYLAV__EXTERNAL_UNMANAGED_SSL")) is None
     EXTERNAL_UNMANAGED_SSL = bool(int(os.getenv("PYLAV__EXTERNAL_UNMANAGED_SSL", "0")))
     data_new["PYLAV__EXTERNAL_UNMANAGED_SSL"] = EXTERNAL_UNMANAGED_SSL
 
+if (EXTERNAL_UNMANAGED_NAME := data.get("PYLAV__EXTERNAL_UNMANAGED_NAME")) is None:
+    EXTERNAL_UNMANAGED_NAME = os.getenv("PYLAV__EXTERNAL_UNMANAGED_NAME") or "ENVAR Node (Unmanaged)"
+    data_new["PYLAV__EXTERNAL_UNMANAGED_NAME"] = EXTERNAL_UNMANAGED_NAME
+
 if (TASK_TIMER_UPDATE_BUNDLED_PLAYLISTS_DAYS := data.get("PYLAV__TASK_TIMER_UPDATE_BUNDLED_PLAYLISTS_DAYS")) is None:
     TASK_TIMER_UPDATE_BUNDLED_PLAYLISTS_DAYS = max(
         int(os.getenv("PYLAV__TASK_TIMER_UPDATE_BUNDLED_PLAYLISTS_DAYS", "1")), 1
